[Mesa-dev] [PATCH 06/10] swrast: rename texture fetch functions (pt. 5)

Brian Paul brianp at vmware.com
Sat Apr 5 15:50:57 PDT 2014


sed commands:
s/srgba8/A8B8G8R8_SRGB/g
s/sargb8/B8G8R8A8_SRGB/g
s/sabgr8/R8G8B8A8_SRGB/g
s/sxbgr8/R8G8B8X8_SRGB/g
s/sla8/L8A8_SRGB/g
s/sl8/L_SRGB8/g
s/srgb8/BGR_SRGB8/g
---
 src/mesa/swrast/s_texfetch.c     |   42 +++++++++++++++++++-------------------
 src/mesa/swrast/s_texfetch_tmp.h |   28 ++++++++++++-------------
 2 files changed, 35 insertions(+), 35 deletions(-)

diff --git a/src/mesa/swrast/s_texfetch.c b/src/mesa/swrast/s_texfetch.c
index cecdd5e..54ef464 100644
--- a/src/mesa/swrast/s_texfetch.c
+++ b/src/mesa/swrast/s_texfetch.c
@@ -597,15 +597,15 @@ texfetch_funcs[] =
    /* Packed sRGB formats */
    {
       MESA_FORMAT_A8B8G8R8_SRGB,
-      fetch_texel_1d_srgba8,
-      fetch_texel_2d_srgba8,
-      fetch_texel_3d_srgba8
+      fetch_texel_1d_A8B8G8R8_SRGB,
+      fetch_texel_2d_A8B8G8R8_SRGB,
+      fetch_texel_3d_A8B8G8R8_SRGB
    },
    {
       MESA_FORMAT_B8G8R8A8_SRGB,
-      fetch_texel_1d_sargb8,
-      fetch_texel_2d_sargb8,
-      fetch_texel_3d_sargb8
+      fetch_texel_1d_B8G8R8A8_SRGB,
+      fetch_texel_2d_B8G8R8A8_SRGB,
+      fetch_texel_3d_B8G8R8A8_SRGB
    },
    {
       MESA_FORMAT_B8G8R8X8_SRGB,
@@ -615,35 +615,35 @@ texfetch_funcs[] =
    },
    {
       MESA_FORMAT_R8G8B8A8_SRGB,
-      fetch_texel_1d_sabgr8,
-      fetch_texel_2d_sabgr8,
-      fetch_texel_3d_sabgr8
+      fetch_texel_1d_R8G8B8A8_SRGB,
+      fetch_texel_2d_R8G8B8A8_SRGB,
+      fetch_texel_3d_R8G8B8A8_SRGB
    },
    {
       MESA_FORMAT_R8G8B8X8_SRGB,
-      fetch_texel_1d_sxbgr8,
-      fetch_texel_2d_sxbgr8,
-      fetch_texel_3d_sxbgr8
+      fetch_texel_1d_R8G8B8X8_SRGB,
+      fetch_texel_2d_R8G8B8X8_SRGB,
+      fetch_texel_3d_R8G8B8X8_SRGB
    },
    {
       MESA_FORMAT_L8A8_SRGB,
-      fetch_texel_1d_sla8,
-      fetch_texel_2d_sla8,
-      fetch_texel_3d_sla8
+      fetch_texel_1d_L8A8_SRGB,
+      fetch_texel_2d_L8A8_SRGB,
+      fetch_texel_3d_L8A8_SRGB
    },
 
    /* Array sRGB formats */
    {
       MESA_FORMAT_L_SRGB8,
-      fetch_texel_1d_sl8,
-      fetch_texel_2d_sl8,
-      fetch_texel_3d_sl8
+      fetch_texel_1d_L_SRGB8,
+      fetch_texel_2d_L_SRGB8,
+      fetch_texel_3d_L_SRGB8
    },
    {
       MESA_FORMAT_BGR_SRGB8,
-      fetch_texel_1d_srgb8,
-      fetch_texel_2d_srgb8,
-      fetch_texel_3d_srgb8
+      fetch_texel_1d_BGR_SRGB8,
+      fetch_texel_2d_BGR_SRGB8,
+      fetch_texel_3d_BGR_SRGB8
    },
 
    /* Packed float formats */
diff --git a/src/mesa/swrast/s_texfetch_tmp.h b/src/mesa/swrast/s_texfetch_tmp.h
index ea0d56a..651b5cb 100644
--- a/src/mesa/swrast/s_texfetch_tmp.h
+++ b/src/mesa/swrast/s_texfetch_tmp.h
@@ -975,9 +975,9 @@ static void FETCH(I_UNORM16)( const struct swrast_texture_image *texImage,
 
 
 
 /* Fetch texel from 1D, 2D or 3D srgb8 texture, return 4 GLfloats */
 /* Note: component order is same as for MESA_FORMAT_BGR_UNORM8 */
-static void FETCH(srgb8)(const struct swrast_texture_image *texImage,
+static void FETCH(BGR_SRGB8)(const struct swrast_texture_image *texImage,
                          GLint i, GLint j, GLint k, GLfloat *texel )
 {
    const GLubyte *src = TEXEL_ADDR(GLubyte, texImage, i, j, k, 3);
@@ -989,8 +989,8 @@ static void FETCH(srgb8)(const struct swrast_texture_image *texImage,
 
 
 
-/* Fetch texel from 1D, 2D or 3D srgba8 texture, return 4 GLfloats */
-static void FETCH(srgba8)(const struct swrast_texture_image *texImage,
+/* Fetch texel from 1D, 2D or 3D A8B8G8R8_SRGB texture, return 4 GLfloats */
+static void FETCH(A8B8G8R8_SRGB)(const struct swrast_texture_image *texImage,
                           GLint i, GLint j, GLint k, GLfloat *texel )
 {
    const GLuint s = *TEXEL_ADDR(GLuint, texImage, i, j, k, 1);
@@ -1002,8 +1002,8 @@ static void FETCH(srgba8)(const struct swrast_texture_image *texImage,
 
 
 
-/* Fetch texel from 1D, 2D or 3D sargb8 texture, return 4 GLfloats */
-static void FETCH(sargb8)(const struct swrast_texture_image *texImage,
+/* Fetch texel from 1D, 2D or 3D B8G8R8A8_SRGB texture, return 4 GLfloats */
+static void FETCH(B8G8R8A8_SRGB)(const struct swrast_texture_image *texImage,
                           GLint i, GLint j, GLint k, GLfloat *texel )
 {
    const GLuint s = *TEXEL_ADDR(GLuint, texImage, i, j, k, 1);
@@ -1015,8 +1015,8 @@ static void FETCH(sargb8)(const struct swrast_texture_image *texImage,
 
 
 
-/* Fetch texel from 1D, 2D or 3D sabgr8 texture, return 4 GLfloats */
-static void FETCH(sabgr8)(const struct swrast_texture_image *texImage,
+/* Fetch texel from 1D, 2D or 3D R8G8B8A8_SRGB texture, return 4 GLfloats */
+static void FETCH(R8G8B8A8_SRGB)(const struct swrast_texture_image *texImage,
                           GLint i, GLint j, GLint k, GLfloat *texel )
 {
    const GLuint s = *TEXEL_ADDR(GLuint, texImage, i, j, k, 1);
@@ -1027,8 +1027,8 @@ static void FETCH(sabgr8)(const struct swrast_texture_image *texImage,
 }
 
 
-/* Fetch texel from 1D, 2D or 3D sabgr8 texture, return 4 GLfloats */
-static void FETCH(sxbgr8)(const struct swrast_texture_image *texImage,
+/* Fetch texel from 1D, 2D or 3D R8G8B8A8_SRGB texture, return 4 GLfloats */
+static void FETCH(R8G8B8X8_SRGB)(const struct swrast_texture_image *texImage,
                           GLint i, GLint j, GLint k, GLfloat *texel )
 {
    const GLuint s = *TEXEL_ADDR(GLuint, texImage, i, j, k, 1);
@@ -1039,8 +1039,8 @@ static void FETCH(sxbgr8)(const struct swrast_texture_image *texImage,
 }
 
 
-/* Fetch texel from 1D, 2D or 3D sl8 texture, return 4 GLfloats */
-static void FETCH(sl8)(const struct swrast_texture_image *texImage,
+/* Fetch texel from 1D, 2D or 3D L_SRGB8 texture, return 4 GLfloats */
+static void FETCH(L_SRGB8)(const struct swrast_texture_image *texImage,
                        GLint i, GLint j, GLint k, GLfloat *texel )
 {
    const GLubyte *src = TEXEL_ADDR(GLubyte, texImage, i, j, k, 1);
@@ -1052,8 +1052,8 @@ static void FETCH(sl8)(const struct swrast_texture_image *texImage,
 
 
 
-/* Fetch texel from 1D, 2D or 3D sla8 texture, return 4 GLfloats */
-static void FETCH(sla8)(const struct swrast_texture_image *texImage,
+/* Fetch texel from 1D, 2D or 3D L8A8_SRGB texture, return 4 GLfloats */
+static void FETCH(L8A8_SRGB)(const struct swrast_texture_image *texImage,
                        GLint i, GLint j, GLint k, GLfloat *texel )
 {
    const GLubyte *src = TEXEL_ADDR(GLubyte, texImage, i, j, k, 2);
@@ -975,9 +975,9 @@ static void FETCH(I_UNORM16)( const struct swrast_texture_image *texImage,
 
 
-/* Fetch texel from 1D, 2D or 3D srgb8 texture, return 4 GLfloats */
+/* Fetch texel from 1D, 2D or 3D BGR_SRGB8 texture, return 4 GLfloats */
 /* Note: component order is same as for MESA_FORMAT_BGR_UNORM8 */
-- 
1.7.10.4



More information about the mesa-dev mailing list